@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2018 Volker Krause <vkrause@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Volker Krause <vkrause@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -62,14 +62,39 @@ QVariant Field::value() const
     if (v.isEmpty()) {
         v = d->pass->d->message(d->obj.value(QLatin1String("value")).toString());
     }
-    // TODO number and date/time detection
+
+    const auto dt = QDateTime::fromString(v, Qt::ISODate);
+    if (dt.isValid()) {
+        return dt;
+    }
+
+    // TODO number detection
     return v;
 }
 
 QString Field::valueDisplayString() const
 {
-    // TODO respect number and date/time formatting options
-    return value().toString();
+    const auto v = value();
+    // see
+    // https://developer.apple.com/library/archive/documentation/UserExperience/Reference/PassKit_Bundle/Chapters/FieldDictionary.html#//apple_ref/doc/uid/TP40012026-CH4-SW6
+    // however, real-world data doesn't strictly follow that, so we have to guess a bit here...
+    if (v.type() == QVariant::DateTime) {
+        const auto dt = v.toDateTime();
+        auto fmt = QLocale::ShortFormat;
+        const auto dtStyle = d->obj.value(QLatin1String("dateStyle")).toString();
+        if (dtStyle == QLatin1String("PKDateStyleLong") || dtStyle == QLatin1String("PKDateStyleFull")) {
+            fmt = QLocale::LongFormat;
+        }
+        const auto timeStyle = d->obj.value(QLatin1String("timeStyle")).toString();
+        if (timeStyle == QLatin1String("PKDateStyleNone") || (timeStyle.isEmpty() && !dtStyle.isEmpty() && dt.time() == QTime(0, 0))) {
+            return QLocale().toString(dt.date(), fmt);
+        }
+
+        return QLocale().toString(dt, fmt);
+    }
+
+    // TODO respect number formatting options
+    return value().toString().trimmed();
 }
 
 QString Field::changeMessage() const
